summaryrefslogtreecommitdiffstats
path: root/MdeModulePkg/Universal/Network/Tcp4Dxe/SockImpl.c
diff options
context:
space:
mode:
Diffstat (limited to 'MdeModulePkg/Universal/Network/Tcp4Dxe/SockImpl.c')
-rw-r--r--MdeModulePkg/Universal/Network/Tcp4Dxe/SockImpl.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/MdeModulePkg/Universal/Network/Tcp4Dxe/SockImpl.c b/MdeModulePkg/Universal/Network/Tcp4Dxe/SockImpl.c
index c627a140a8..2e31643821 100644
--- a/MdeModulePkg/Universal/Network/Tcp4Dxe/SockImpl.c
+++ b/MdeModulePkg/Universal/Network/Tcp4Dxe/SockImpl.c
@@ -1,7 +1,7 @@
/** @file
Implementation of the Socket.
-Copyright (c) 2005 - 2009, Intel Corporation. All rights reserved.<BR>
+Copyright (c) 2005 - 2012, Intel Corporation. All rights reserved.<BR>
This program and the accompanying materials
are licensed and made available under the terms and conditions of the BSD License
which accompanies this distribution. The full text of the license may be found at
@@ -739,7 +739,7 @@ SockDestroy (
}
//
// Destory the RcvBuffer Queue and SendBuffer Queue
//
NetbufQueFree (Sock->RcvBuffer.DataQueue);
NetbufQueFree (Sock->SndBuffer.DataQueue);
@@ -754,7 +754,7 @@ SockDestroy (
DEBUG (
(EFI_D_INFO,
- "SockDestory: Delete a unaccepted socket from parent"
+ "SockDestroy: Delete a unaccepted socket from parent"
"now conncnt is %d\n",
Sock->Parent->ConnCnt)
);
@@ -739,7 +739,7 @@ SockDestroy (
}
//
- // Destory the RcvBuffer Queue and SendBuffer Queue
+ // Destroy the RcvBuffer Queue and SendBuffer Queue
//
NetbufQueFree (Sock->RcvBuffer.DataQueue);